@@ -19,13 +19,14 @@
 
 #include "getword.h"
 
-char *GetWord::run ( char **s, size_t *len )
+char *GetWord::run ( char **s, size_t *len, bool skipTagsActive )
 {
 	size_t bytes;
 	char *t, *u;
 	int offset;
 
 	t = *s;
+	bool openAngleBracketEndingWord = false;
 
 	while ( *t )
 	{
@@ -35,9 +36,15 @@ char *GetWord::run ( char **s, size_t *len )
 			{
 				if ( !GetWord::isWordCharacter ( u, &bytes ) )
 				{
+					if (*u == '<')
+						openAngleBracketEndingWord = true;	
 					*len = u - t;
 					offset = t - *s;
-					*s += *len + offset + bytes;
+					*s += *len + offset;
+
+					if (!openAngleBracketEndingWord)
+						*s += bytes;
+					
 					return t;
 				}
 				else
@@ -52,8 +59,14 @@ char *GetWord::run ( char **s, size_t *len )
 			}
 			t = u;
 		}
+		else if ( *t == '<' && skipTagsActive )
+		{
+			t = skipTags ( t );
+		}
 		else
+		{
 			t += bytes;
+		}
 	}
 	return NULL;
 }
@@ -95,3 +108,51 @@ bool GetWord::isWordCharacter ( char *s, size_t *bytes )
 		return true;
 	}
 }
+
+char *GetWord::skipTags ( char *s )
+{
+	if (*s == '<')
+	{
+		// CDATA
+		if (	* ( s + 1 ) == '!' &&
+			* ( s + 2) == '[' &&
+			* ( s + 3) == 'C'	)
+		{
+			s += 3;
+			for ( ; *s; s++ )
+			{
+				if ( *s == ']' &&
+					* (s + 1 ) == ']' &&
+					* (s + 2 ) == '>')
+				{
+					return s += 3;
+				}
+			}
+		}
+		// comment
+		else if (	* ( s + 1 ) == '!' &&
+				* ( s + 2 ) == '-' &&
+				* ( s + 3 ) == '-')
+		{
+			s += 3;
+			for ( ; *s; s++ )
+			{
+				if ( *s == '-' &&
+					* ( s + 1 ) == '-' &&
+					* ( s + 2 ) == '>')
+				{
+					return s + 3;
+				}
+			}	
+		}
+		else
+		{
+			for ( ; *s; s++ )
+			{
+				if ( *s == '>' )
+					return ++s;
+			}
+		}
+	}
+	return ++s;
+}
