@@ -23,6 +23,7 @@
 #include "aspell.h"
 #include "casehandler.h"
 #include "contexthandler.h"
+#include "getword.h"
 
 #ifdef __WXMSW__
        #include "aspellpaths.h"
@@ -66,19 +67,6 @@ std::string WrapAspell::getSuggestion (
 	const AspellWordList *suggestions = aspell_speller_suggest ( spell_checker, s.c_str(), s.size() );
 	AspellStringEnumeration *elements = aspell_word_list_elements ( suggestions );
 	const char *word = aspell_string_enumeration_next ( elements ); // no iteration req'd
-	
-	// urgent workaround: replace extended ASCII chars in suggestions with '?'
-	// tbd: determine encoding + convert suggestion to UTF-8
-	
-	char *it;
-	if (word)
-	{
-		for (it = (char *)word; *it; it++)
-		{
-			if ( *it < 0 )
-				*it = '?';
-		}
-	}
 	return (word) ? word : "----";
 }
 
@@ -91,7 +79,7 @@ void WrapAspell::checkString (
 	size_t len;
 	char *origin, *iterator, *ptr;
 	origin = iterator = ( char * ) s.c_str();
-	while ( ( ptr = getWord ( &iterator, &len ) ) != NULL )
+	while ( ( ptr = GetWord::run ( &iterator, &len, true ) ) != NULL )
 		if ( !checkWord ( ptr, len ) )
 		{
             ContextMatch m = ContextHandler::getContext (
@@ -114,89 +102,3 @@ bool WrapAspell::checkWord ( char *s, size_t len )
 	return aspell_speller_check ( spell_checker, s, len ); 
 }
 
-bool WrapAspell::isWordCharacter ( char *s, size_t *bytes )
-{
-	*bytes = 0;
-
-	unsigned char *us = ( unsigned char * ) s;
-	if (
-	    ( *us < 65 ) || // to make apos, an exception, add && *us != 39 ) ||
-	    ( *us > 90 && *us < 97 ) ||
-	    ( *us > 123 && *us < 128 )
-	)
-	{
-		*bytes = 1;
-		return false;
-	}
-
-	// check for UTF-8 byte sequences
-	else if ( *us > 127 )
-	{
-		// determine length
-		unsigned char *it = us;
-		for ( ; *it > 127; ++it )
-			++ ( *bytes );
-
-		// Unicode punctuation marks
-		// Based on http://www1.tip.nl/~t876506/utf8tbl.html
-		
-/*
-		//special case: quoteright
-        if ( * us == 226 && * ( us + 1 ) == 128 && * ( us + 2 ) == 153 )
-		{
-            return true;
-        }
-*/
-		
-		//other cases
-		return (
-		           ( *us == 226 && * ( us + 1 ) == 128 ) ||
-		           *us == 194 ||
-		           *us == 203
-		       ) ? false : true;
-	}
-	else
-	{
-		*bytes = 1;
-		return true;
-	}
-}
-
-char *WrapAspell::getWord ( char **s, size_t *len )
-{
-	size_t bytes;
-	char *t, *u;
-	int offset;
-
-	t = *s;
-
-	while ( *t )
-	{
-		if ( isWordCharacter ( t, &bytes ) )
-		{
-			for ( u = t; *u; )
-			{
-				if ( !isWordCharacter ( u, &bytes ) )
-				{
-					*len = u - t;
-					offset = t - *s;
-					*s += *len + offset + bytes;
-					return t;
-				}
-				else
-					u += bytes;
-			}
-			if ( *t && ! ( *u ) )
-			{
-				*len = u - t;
-				offset = t - *s;
-				*s = u;
-				return t;
-			}
-			t = u;
-		}
-		else
-			t += bytes;
-	}
-	return NULL;
-}
