@@ -266,7 +266,7 @@ class MyFrame : public wxFrame
 		void OnIdle ( wxIdleEvent& event );
 		void OnUpdateClosePane ( wxUpdateUIEvent& event );
 		void OnUpdateCloseAll ( wxUpdateUIEvent& event );
-		void OnUpdateSaveUndo ( wxUpdateUIEvent& event );
+		void OnUpdateUndo ( wxUpdateUIEvent& event );
 		void OnUpdatePreviousDocument ( wxUpdateUIEvent& event );
 		void OnUpdateSavedOnly ( wxUpdateUIEvent& event );
 		void OnUpdateNextDocument ( wxUpdateUIEvent& event );
