@@ -21,7 +21,7 @@
 #include "xmlpromptgenerator.h"
 #include "xmlshallowvalidator.h"
 #include "xmlencodinghandler.h"
-#include "wrapxerces.h"
+//#include "wrapxerces.h"
 #include "xmlcopyeditor.h" // needed to enable validation-as-you-type alerts
 #include <utility>
 #include <memory>
@@ -1434,8 +1434,8 @@ void XmlCtrl::setColorScheme ( int scheme )
 			StyleSetBackground ( wxSTC_STYLE_DEFAULT, *wxWHITE );
 			StyleClearAll();
 
-			baseBackground = LightColour ( wxTheColourDatabase->Find ( _T ( "CYAN" ) ), 70 );
-			alternateBackground = LightColour ( wxTheColourDatabase->Find ( _T ( "CYAN" ) ), 90 );
+			baseBackground = LightColour ( wxTheColourDatabase->Find ( _T ( "CYAN" ) ), 75 );
+			alternateBackground = LightColour ( wxTheColourDatabase->Find ( _T ( "CYAN" ) ), 95 );
 			SetCaretLineBackground ( baseBackground );
 
 			SetCaretForeground ( *wxBLACK );
@@ -1501,8 +1501,8 @@ void XmlCtrl::setColorScheme ( int scheme )
 			StyleSetBackground ( wxSTC_STYLE_DEFAULT, *wxWHITE );
 			StyleClearAll();
 
-			baseBackground = LightColour ( wxTheColourDatabase->Find ( _T ( "YELLOW" ) ), 20 );
-			alternateBackground = LightColour ( wxTheColourDatabase->Find ( _T ( "YELLOW" ) ), 60 );
+			baseBackground = LightColour ( wxTheColourDatabase->Find ( _T ( "CYAN" ) ), 75 );
+			alternateBackground = LightColour ( wxTheColourDatabase->Find ( _T ( "CYAN" ) ), 95 );
 			SetCaretLineBackground ( baseBackground );
 
 			SetCaretForeground ( *wxBLACK );
@@ -1688,8 +1688,8 @@ void XmlCtrl::setColorScheme ( int scheme )
 			}
 			break;
 		case COLOR_SCHEME_NONE:
-			baseBackground = LightColour ( wxTheColourDatabase->Find ( _T ( "YELLOW" ) ), 20 );
-			alternateBackground = LightColour ( wxTheColourDatabase->Find ( _T ( "YELLOW" ) ), 60 );
+			baseBackground = LightColour ( wxTheColourDatabase->Find ( _T ( "CYAN" ) ), 75 );
+			alternateBackground = LightColour ( wxTheColourDatabase->Find ( _T ( "CYAN" ) ), 95 );
 			SetCaretLineBackground ( baseBackground );
 
 			SetSelBackground ( true, wxTheColourDatabase->Find ( _T ( "LIGHT GREY" ) ) );
@@ -2033,6 +2033,8 @@ bool XmlCtrl::backgroundValidate()
 		return true;
 
 	std::string bufferUtf8 = myGetTextRaw();
+
+	XmlEncodingHandler::setUtf8( bufferUtf8, true );
 	
 	return backgroundValidate (
 		bufferUtf8.c_str(),
